
Module documentation
********************

Underscore notation
===================

.. autofunction:: synthetic.naming_convention
.. autofunction:: synthetic.synthesize_constructor
.. autofunction:: synthetic.synthesize_member
.. autofunction:: synthetic.synthesize_property

CamelCase notation
==================

Sorry Guido, but I like CamelCase.

.. autofunction:: synthetic.namingConvention
.. autofunction:: synthetic.synthesizeConstructor
.. autofunction:: synthetic.synthesizeMember
.. autofunction:: synthetic.synthesizeProperty

